==> 1.0.3.tar.gz: lib/src/widgets/text_add_widget.dart <==
import 'dart:math';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:ocg_app/ocg_app.dart';
import 'package:ocg_story/src/models/basic.dart';
import 'package:ocg_story/src/widgets/color_box.dart';

class TextAddWidget extends StatefulWidget {
  final StoryTextData data;
  final Function(StoryBasic) onSelected;

  const TextAddWidget({Key key, @required this.onSelected, this.data})
      : super(key: key);
  @override
  State<StatefulWidget> createState() => _TextAddWidgetState();
}

class _TextAddWidgetState extends State<TextAddWidget> {
  TextBoxDecoration _boxDecoration;

  List<Color> colors = [
    Colors.redAccent,
    Color(0xffE4E4E4),
    Colors.greenAccent,
    Colors.white,
    Colors.black,
    Color(0xff222930)
  ];
  Color selectedColor;
  Widget textWidget;
  @override
  void initState() {
    super.initState();
    _boxDecoration = widget.data?.decoration ?? defaultDecoration;
    selectedColor = _boxDecoration.filled
        ? _boxDecoration.decoration.color
        : _boxDecoration.style.color;
    controller.text = widget.data?.data;
    controller.addListener(() {
      setState(() {});
    });
    WidgetsBinding.instance.addPostFrameCallback((val) {
      focusNode.requestFocus();
    });
  }

  void onTap(Color color) {
    setState(() {
      selectedColor = color;
      _boxDecoration.decoration = _boxDecoration.decoration.copyWith(
          color: _boxDecoration.filled ? selectedColor : Colors.transparent);
      _boxDecoration.style = _boxDecoration.style.copyWith(color: textColor);
    });
  }

  final TextBoxDecoration defaultDecoration = TextBoxDecoration(
      filled: true,
      style: TextStyle(
          fontSize: 24.0,
          fontWeight: FontWeight.w700,
          color: Colors.white,
          fontFamily: "B612Mono"),
      decoration: BoxDecoration(
        color: Colors.black,
        borderRadius: BorderRadius.circular(8.0),
      ));

  FocusNode focusNode = FocusNode();
  TextEditingController controller = TextEditingController();
  @override
  Widget build(BuildContext context) {
    textWidget = Container(
      padding: StoryTextData.TEXT_PADDING,
      constraints: BoxConstraints(
          maxWidth: MediaQuery.of(context).size.width * 3 / 4, minWidth: 45.0),
      width: (textSize) * 21.0,
      decoration: _boxDecoration.decoration,
      child: TextField(
        focusNode: focusNode,
        controller: controller,
        maxLines: null,
        expands: false,
        cursorColor: textColor,
        textAlign: _boxDecoration.textAlign,
        decoration: InputDecoration(
          border: InputBorder.none,
        ),
        style: _boxDecoration.style,
      ),
    );
    return WillPopScope(
      onWillPop: () async {
        widget.onSelected(null);
        return false;
      },
      child: SafeArea(
        child: Scaffold(
          backgroundColor: Colors.transparent,
          body: Stack(
            fit: StackFit.expand,
            alignment: Alignment.topRight,
            children: <Widget>[
              Center(
                child: textWidget,
              ),
              Padding(
                padding: const EdgeInsets.only(top: 8.0),
                child: Column(
                  mainAxisSize: MainAxisSize.min,
                  crossAxisAlignment: CrossAxisAlignment.end,
                  children: <Widget>[
                    FlatButton(
                        onPressed: () {
                          popBack();
                        },
                        child: Text(
                          "Done",
                          style: TextStyle(color: Colors.white, fontSize: 16.0),
                        )),
                    buildSelection(),
                    SizedBox(
                      height: 8,
                    ),
                    buildAlignmentButton(_boxDecoration.textAlign)
                  ],
                ),
              )
            ],
          ),
          bottomNavigationBar: Container(
            height: 60.0,
            alignment: Alignment.center,
            child: ListView.builder(
              itemBuilder: (context, index) {
                Color color = colors[index];
                return ColorBox(
                  color: color,
                  onTap: onTap,
                  size: 32,
                  smallBorder: selectedColor != color,
                );
              },
              itemCount: colors.length,
              shrinkWrap: true,
              scrollDirection: Axis.horizontal,
            ),
          ),
        ),
      ),
    );
  }

  get textColor {
    if (!_boxDecoration.filled) {
      return selectedColor;
    }
    var o = (((selectedColor.red * 299) +
            (selectedColor.green * 587).toInt() +
            ((selectedColor.blue) * 114).toInt()) /
        1000);
    return (o > 125) ? Colors.black : Colors.white;
  }

  get textSize {
    int i = 0;
    if (controller.text.length == 0) {
      return 1;
    }
    controller.text.split("\n").forEach((val) {
      i = max(val.length, i);
    });
    return i;
  }

  void popBack() {
    if (controller.text == null || controller.text.length == 0) {
      widget.onSelected(null);
      return;
    }
    widget.onSelected(StoryTextData(
      id: IDHelper().generateId(),
      data: controller.text,
      decoration: _boxDecoration,
    ));
  }

  Widget buildSelection() {
    return RaisedButton(
      onPressed: () {
        setState(() {
          _boxDecoration.filled = !_boxDecoration.filled;
        });
      },
      color: !_boxDecoration.filled ? Colors.black54 : Colors.white,
      shape: CircleBorder(),
      child: Icon(
        Icons.text_fields,
        color: !_boxDecoration.filled ? Colors.white : Colors.black,
        size: 28.0,
      ),
      padding: EdgeInsets.all(8.0),
      elevation: 0.0,
    );
  }

  List<TextAlign> aligns = [TextAlign.left, TextAlign.center, TextAlign.right];
  int currentAlign = 0;
  Widget buildAlignmentButton(TextAlign align) {
    Map icons = {
      TextAlign.center: Icons.format_align_center,
      TextAlign.left: Icons.format_align_left,
      TextAlign.right: Icons.format_align_right,
    };
    return RaisedButton(
      elevation: 0.0,
      shape: CircleBorder(),
      color: Colors.black54,
      onPressed: () {
        setState(() {
          _boxDecoration.textAlign = aligns[(++currentAlign) % 3];
        });
      },
      padding: EdgeInsets.all(12.0),
      child: Icon(
        icons[align],
        size: 20.0,
        color: Colors.white,
      ),
    );
  }

  @override
  void dispose() {
    super.dispose();
    SystemChrome.restoreSystemUIOverlays();
  }
}

==> 1.0.4.tar.gz: lib/src/widgets/text_add_widget.dart <==
import 'dart:math';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:ocg_app/ocg_app.dart';
import 'package:ocg_story/src/models/basic.dart';
import 'package:ocg_story/src/widgets/color_box.dart';

class TextAddWidget extends StatefulWidget {
  final StoryTextData data;
  final Function(StoryBasic) onSelected;

  const TextAddWidget({Key key, @required this.onSelected, this.data})
      : super(key: key);
  @override
  State<StatefulWidget> createState() => _TextAddWidgetState();
}

class _TextAddWidgetState extends State<TextAddWidget> {
  TextBoxDecoration _boxDecoration;

  List<Color> colors = [
    Colors.redAccent,
    Color(0xffE4E4E4),
    Colors.greenAccent,
    Colors.white,
    Colors.black,
    Color(0xff222930)
  ];
  Color selectedColor;
  Widget textWidget;
  @override
  void initState() {
    super.initState();
    _boxDecoration = widget.data?.decoration ?? defaultDecoration;
    selectedColor = _boxDecoration.filled
        ? _boxDecoration.decoration.color
        : _boxDecoration.style.color;
    controller.text = widget.data?.data;
    controller.addListener(() {
      setState(() {});
    });
    WidgetsBinding.instance.addPostFrameCallback((val) {
      focusNode.requestFocus();
    });
  }

  void onTap(Color color) {
    setState(() {
      selectedColor = color;
      _boxDecoration.decoration = _boxDecoration.decoration.copyWith(
          color: _boxDecoration.filled ? selectedColor : Colors.transparent);
      _boxDecoration.style = _boxDecoration.style.copyWith(color: textColor);
    });
  }

  final TextBoxDecoration defaultDecoration = TextBoxDecoration(
      filled: true,
      style: TextStyle(
          fontSize: 24.0,
          fontWeight: FontWeight.w700,
          color: Colors.white,
          fontFamily: "B612Mono"),
      decoration: BoxDecoration(
        color: Colors.black,
        borderRadius: BorderRadius.circular(8.0),
      ));

  FocusNode focusNode = FocusNode();
  TextEditingController controller = TextEditingController();
  @override
  Widget build(BuildContext context) {
    textWidget = Container(
      // padding: StoryTextData.TEXT_PADDING,
      constraints: BoxConstraints(
          maxWidth: MediaQuery.of(context).size.width * 3 / 4, minWidth: 45.0),
      width: (textSize) * (_boxDecoration.style.fontSize * 0.75),
      decoration: _boxDecoration.decoration,
      child: TextField(
        focusNode: focusNode,
        controller: controller,
        maxLines: null,
        expands: false,
        cursorColor: textColor,
        textAlign: _boxDecoration.textAlign,
        decoration: InputDecoration(
          border: InputBorder.none,
        ),
        style: _boxDecoration.style,
      ),
    );
    return WillPopScope(
      onWillPop: () async {
        widget.onSelected(null);
        return false;
      },
      child: SafeArea(
        child: Scaffold(
          backgroundColor: Colors.transparent,
          body: Stack(
            fit: StackFit.expand,
            alignment: Alignment.topRight,
            children: <Widget>[
              Center(
                child: textWidget,
              ),
              Padding(
                padding: const EdgeInsets.only(top: 8.0),
                child: Column(
                  mainAxisSize: MainAxisSize.min,
                  crossAxisAlignment: CrossAxisAlignment.end,
                  children: <Widget>[
                    FlatButton(
                        onPressed: () {
                          popBack();
                        },
                        child: Text(
                          "Done",
                          style: TextStyle(color: Colors.white, fontSize: 16.0),
                        )),
                    buildSelection(),
                    SizedBox(
                      height: 8,
                    ),
                    buildAlignmentButton(_boxDecoration.textAlign),
                    SizedBox(
                      height: 8,
                    ),
                    buildFontSize(_boxDecoration.style.fontSize),
                  ],
                ),
              )
            ],
          ),
          bottomNavigationBar: Container(
            height: 60.0,
            alignment: Alignment.center,
            child: ListView.builder(
              itemBuilder: (context, index) {
                Color color = colors[index];
                return ColorBox(
                  color: color,
                  onTap: onTap,
                  size: 32,
                  smallBorder: selectedColor != color,
                );
              },
              itemCount: colors.length,
              shrinkWrap: true,
              scrollDirection: Axis.horizontal,
            ),
          ),
        ),
      ),
    );
  }

  get textColor {
    if (!_boxDecoration.filled) {
      return selectedColor;
    }
    var o = (((selectedColor.red * 299) +
            (selectedColor.green * 587).toInt() +
            ((selectedColor.blue) * 114).toInt()) /
        1000);
    return (o > 125) ? Colors.black : Colors.white;
  }

  get textSize {
    int i = 0;
    if (controller.text.length == 0) {
      return 1;
    }
    controller.text.split("\n").forEach((val) {
      i = max(val.length, i);
    });
    return i;
  }

  void popBack() {
    if (controller.text == null || controller.text.length == 0) {
      widget.onSelected(null);
      return;
    }
    widget.onSelected(StoryTextData(
      id: IDHelper().generateId(),
      data: controller.text,
      decoration: _boxDecoration,
    ));
  }

  Widget buildSelection() {
    return RaisedButton(
      onPressed: () {
        setState(() {
          _boxDecoration.filled = !_boxDecoration.filled;
          _boxDecoration.decoration = _boxDecoration.decoration.copyWith(
              color:
                  _boxDecoration.filled ? selectedColor : Colors.transparent);
          _boxDecoration.style =
              _boxDecoration.style.copyWith(color: textColor);
        });
      },
      color: !_boxDecoration.filled ? Colors.black54 : Colors.white,
      shape: CircleBorder(),
      child: Icon(
        Icons.text_fields,
        color: !_boxDecoration.filled ? Colors.white : Colors.black,
        size: 28.0,
      ),
      padding: EdgeInsets.all(8.0),
      elevation: 0.0,
    );
  }

  List<TextAlign> aligns = [TextAlign.left, TextAlign.center, TextAlign.right];
  int currentAlign = 0;

  Widget buildAlignmentButton(TextAlign align) {
    Map icons = {
      TextAlign.center: Icons.format_align_center,
      TextAlign.left: Icons.format_align_left,
      TextAlign.right: Icons.format_align_right,
    };
    return RaisedButton(
      elevation: 0.0,
      shape: CircleBorder(),
      color: Colors.black54,
      onPressed: () {
        setState(() {
          _boxDecoration.textAlign = aligns[(++currentAlign) % 3];
        });
      },
      padding: EdgeInsets.all(12.0),
      child: Icon(
        icons[align],
        size: 20.0,
        color: Colors.white,
      ),
    );
  }

  TextEditingController _numberController = TextEditingController();

  Widget buildFontSize(double fontSize) {
    return RaisedButton(
      elevation: 0.0,
      shape: CircleBorder(),
      color: Colors.black54,
      onPressed: () async {
        _numberController.text = "${_boxDecoration.style.fontSize.toInt()}";
        int value = await showDialog(
          context: context,
          builder: (context) => AlertDialog(
            title: Text("Enter Size"),
            content: TextFormField(
              controller: _numberController,
              keyboardType: TextInputType.number,
              inputFormatters: [FilteringTextInputFormatter.digitsOnly],
              decoration: InputDecoration(
                hintText: "14",
              ),
            ),
            actions: [
              FlatButton(
                  onPressed: () {
                    Navigator.of(context).pop();
                  },
                  child: Text("Cancel")),
              FlatButton(
                  onPressed: () {
                    int value = int.tryParse(_numberController.text);
                    if ((value ?? 0) > 50) {
                      AppUIHelper.of(context)
                          .showToast(text: "Size can not be large than 50");
                      return;
                    }
                    Navigator.of(context).pop(value);
                  },
                  child: Text("Ok"))
            ],
          ),
        );
        if (value != null) {
          setState(() {
            _boxDecoration.style =
                _boxDecoration.style.copyWith(fontSize: value.toDouble());
          });
        }
      },
      padding: EdgeInsets.all(12.0),
      child: Icon(
        Icons.font_download,
        size: 20.0,
        color: Colors.white,
      ),
    );
  }

  @override
  void dispose() {
    super.dispose();
    SystemChrome.restoreSystemUIOverlays();
  }
}
